@@ -86,9 +86,39 @@ class EssClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def CreateConvertTaskApi(self, request):
+        """创建文件转换任务
+
+        :param request: Request instance for CreateConvertTaskApi.
+        :type request: :class:`tencentcloud.ess.v20201111.models.CreateConvertTaskApiRequest`
+        :rtype: :class:`tencentcloud.ess.v20201111.models.CreateConvertTaskApiResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("CreateConvertTaskApi", params, headers=headers)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.CreateConvertTaskApiResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def CreateDocument(self, request):
-        """创建电子文档
+        """创建签署流程电子文档
         适用场景：见创建签署流程接口。
+
         注：该接口需要给对应的流程指定一个模板id，并且填充该模板中需要补充的信息。是“发起流程”接口的前置接口。
 
         :param request: Request instance for CreateDocument.
@@ -151,7 +181,7 @@ class EssClient(AbstractClient):
     def CreateFlowByFiles(self, request):
         """此接口（CreateFlowByFiles）用来通过上传后的pdf资源编号来创建待签署的合同流程。
         适用场景1：适用非制式的合同文件签署。一般开发者自己有完整的签署文件，可以通过该接口传入完整的PDF文件及流程信息生成待签署的合同流程。
-        适用场景2：可通过改接口传入制式合同文件，同时在指定位置添加签署控件。可以起到接口创建临时模板的效果。如果是标准的制式文件，建议使用模板功能生成模板ID进行合同流程的生成。
+        适用场景2：可通过该接口传入制式合同文件，同时在指定位置添加签署控件。可以起到接口创建临时模板的效果。如果是标准的制式文件，建议使用模板功能生成模板ID进行合同流程的生成。
         注意事项：该接口需要依赖“多文件上传”接口生成pdf资源编号（FileIds）进行使用。
 
         :param request: Request instance for CreateFlowByFiles.
@@ -369,6 +399,35 @@ class EssClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def GetTaskResultApi(self, request):
+        """查询转换任务状态
+
+        :param request: Request instance for GetTaskResultApi.
+        :type request: :class:`tencentcloud.ess.v20201111.models.GetTaskResultApiRequest`
+        :rtype: :class:`tencentcloud.ess.v20201111.models.GetTaskResultApiResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("GetTaskResultApi", params, headers=headers)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.GetTaskResultApiResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def StartFlow(self, request):
         """此接口用于发起流程
         适用场景：见创建签署流程接口。
